#!/bin/sh
#
# source: ftp://ftp.musicbrainz.org/pub/musicbrainz/libtunepimp-0.5.3.tar.gz
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft='libtunepimp'
softversion='0.5.3'
packageversion='54.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#-----------------build directories and copy the build script

mkdir -p $dest/install

#-----------------Make the slack-desc files

cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

           |-----handy-ruler----------------------------------------------------|
libtunepimp: libtunepimp (library for media tagging using MusicBrainz servers)
libtunepimp:
libtunepimp: The TunePimp library is a MusicBrainz enabled tagging library that
libtunepimp: allows music files to be looked up.  Once the files have been
libtunepimp: identified, libtunepimp writes new metadata tags to the music files
libtunepimp: and then writes the files to a standardized directory hierarchy.
libtunepimp: 
libtunepimp: libmusicbrainz and libtunepimp are used by various media players to
libtunepimp: identify and tag media files.
libtunepimp:
libtunepimp:
EODESC

#------------------Set correct permissions

cd $src

chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu" \
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \

./configure \
  --prefix=/usr \
  --enable-static=no

make -j2
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#-------------------Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING INSTALL README* TODO $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------make link for kdemultimedia compatibility

cd $dest/usr/include
ln -s tunepimp-0.5 tunepimp

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5